using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Briefcase;
using System.IO;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            FillFolderTree(null);
        }
    }

    private void BindGrid()
    {
        DataTable files = Files.GetFilesFromFolder(int.Parse(TreeView1.SelectedNode.Value.ToString()));
        GridView1.DataSource = files;
        GridView1.DataBind();
    }

    private void FillFolderTree(TreeNode parent)
    {
        int parentfolderid = 0;
        if (parent != null)
        {
            parentfolderid = int.Parse(parent.Value.ToString());
        }

        DataTable folders = Folders.GetSubFolders(parentfolderid);

        if (parent != null)
        {
            parent.ChildNodes.Clear();
        }
        else
        {
            TreeView1.Nodes.Clear();
        }

        foreach (DataRow folder in folders.Rows)
        {
            TreeNode node = new TreeNode();
            node.Text = folder["FolderName"].ToString();
            node.Value = folder["Id"].ToString();
            if (parent == null)
            {
                TreeView1.Nodes.Add(node);
            }
            else
            {
                parent.ChildNodes.Add(node);
            }
        }
        if (TreeView1.SelectedNode != null)
        {
            TreeView1.SelectedNode.Expand();
        }
    }

    protected void TreeView1_SelectedNodeChanged(object sender, EventArgs e)
    {
        FillFolderTree(TreeView1.SelectedNode);
        TextBox2.Text = TreeView1.SelectedNode.Text;
        Label10.Text = TreeView1.SelectedNode.Text;
        BindGrid();
    }

    protected void Button1_Click(object sender, EventArgs e)
    {
        
        try
        {
            if (TreeView1.SelectedNode != null && !CheckBox1.Checked)
            {
                Folders.Create(TextBox1.Text, int.Parse(TreeView1.SelectedNode.Value.ToString()), DateTime.Now);
                FillFolderTree(TreeView1.SelectedNode);

            }
            else
            {
                Folders.Create(TextBox1.Text, 0, DateTime.Now);
                FillFolderTree(null);
            }
        }
        catch (Exception ex)
        {
            Label7.Text = ex.Message;
        }

    }
    protected void Button2_Click(object sender, EventArgs e)
    {
        try
        {
            int id = int.Parse(TreeView1.SelectedNode.Value.ToString());
            Folders.Rename(id, TextBox2.Text);
            //DataTable folders = Folders.GetSubFolders(id);
            TreeView1.SelectedNode.Text = TextBox2.Text;
        }
        catch (Exception ex)
        {
            Label7.Text = ex.Message;
        }

    }
    protected void Button3_Click(object sender, EventArgs e)
    {
        if (TreeView1.SelectedNode != null)
        {
            Folders.Delete(int.Parse(TreeView1.SelectedNode.Value.ToString()));
            Files.DeleteFromFolder(int.Parse(TreeView1.SelectedNode.Value.ToString()));

            foreach (TreeNode node in TreeView1.SelectedNode.ChildNodes)
            {
                Folders.Delete(int.Parse(node.Value.ToString()));
                Files.DeleteFromFolder(int.Parse(node.Value.ToString()));
            }

            if (TreeView1.SelectedNode.Parent != null)
            {
                FillFolderTree(TreeView1.SelectedNode.Parent);
            }
            else
            {
                FillFolderTree(null);
            }
            GridView1.DataSource = null;
            GridView1.DataBind();
        }
        else
        {
            Label7.Text = "Please select folder to be deleted";
        }
    }
    protected void Button4_Click(object sender, EventArgs e)
    {
        try
        {
            if (TreeView1.SelectedNode != null)
            {
                int folderid = int.Parse(TreeView1.SelectedNode.Value);
                string filename = Path.GetFileName(FileUpload1.PostedFile.FileName);
                int filesize = 0;
                if (FileUpload1.HasFile)
                {
                    Stream stream = FileUpload1.PostedFile.InputStream;
                    filesize = FileUpload1.PostedFile.ContentLength;
                    byte[] filedata = new byte[filesize];
                    stream.Read(filedata, 0, filesize);
                    Files.Create(filename, filedata, filesize, folderid, DateTime.Now);
                }
                BindGrid();
            }
            else
            {
                Label7.Text = "Please select destination folder";
            }
        }
        catch (Exception ex)
        {
            Label7.Text = ex.Message;
        }

    }
    protected void GridView1_RowCommand(object sender, GridViewCommandEventArgs e)
    {
        int fileid = int.Parse(GridView1.DataKeys[int.Parse(e.CommandArgument.ToString())].Value.ToString());

        if (e.CommandName == "Download")
        {
            DataTable file = Files.GetFile(fileid);
            byte[] filedata = (byte[])file.Rows[0]["filedata"];
            Response.Clear();
            Response.AddHeader("Content-Disposition", "attachment;filename=" + file.Rows[0]["filename"]);
            Response.BinaryWrite(filedata);
            Response.End();
        }
    }
    protected void GridView1_RowEditing(object sender, GridViewEditEventArgs e)
    {
        GridView1.EditIndex = e.NewEditIndex;
        BindGrid();
    }
    protected void GridView1_RowCancelingEdit(object sender, GridViewCancelEditEventArgs e)
    {
        GridView1.EditIndex = -1;
        BindGrid();
    }
    protected void GridView1_RowUpdating(object sender, GridViewUpdateEventArgs e)
    {
        int fileid = int.Parse(GridView1.DataKeys[e.RowIndex].Value.ToString());
        GridViewRow row = GridView1.Rows[e.RowIndex];
        Files.Rename(fileid, ((TextBox)row.Cells[0].FindControl("TextBox1")).Text);
        GridView1.EditIndex = -1;
        BindGrid();
    }
    protected void GridView1_RowDataBound(object sender, GridViewRowEventArgs e)
    {
    }
    protected void Button1_Click1(object sender, EventArgs e)
    {
        int fileid = int.Parse(((Button)sender).CommandArgument);
        Files.Delete(fileid);
        BindGrid();
    }
}
